@@ -21,11 +21,17 @@ References:
 """
 
 import argparse
+import copy
 import logging
+import pathlib
 import sys
 
+import yaml
+
 from foundationlive import __version__, lib
 
+from . import model
+
 __author__ = "Taylor Monacelli"
 __copyright__ = "Taylor Monacelli"
 __license__ = "MIT"
@@ -46,6 +52,13 @@ _logger = logging.getLogger(__name__)
 # executable/script.
 
 
+def check_positive(value):
+    ivalue = int(value)
+    if ivalue <= 0:
+        raise argparse.ArgumentTypeError(f"{value} is an invalid positive int value")
+    return ivalue
+
+
 def parse_args(args):
     """Parse command line parameters
 
@@ -81,7 +94,12 @@ def parse_args(args):
     parser.add_argument(
         "--data-path", default="data.json", required=True, help="path to data.json"
     )
-
+    parser.add_argument(
+        "--invoice",
+        type=check_positive,
+        required=False,
+        help="Filter out all entries that dont match invoice number",
+    )
     return parser.parse_args(args)
 
 
@@ -110,7 +128,26 @@ def main(args):
     args = parse_args(args)
     setup_logging(args.loglevel)
     _logger.debug("Starting crazy calculations...")
-    lib.view1(args.data_path)
+    records_path = pathlib.Path(args.data_path)
+    with open(records_path, "r") as stream:
+        try:
+            external_data = yaml.safe_load(stream)
+        except yaml.YAMLError as exc:
+            print(exc)
+
+    timesheet = model.Timesheet(**external_data)
+    timesheet2 = copy.deepcopy(timesheet)
+
+    if args.invoice is not None:
+        for day in timesheet.days:
+            if day.invoice != args.invoice:
+                timesheet2.days.remove(day)
+
+    timesheet = timesheet2
+
+    print(lib.view_hours_per_task(timesheet))
+    print(lib.view_hours_worked_per_day(timesheet))
+    print(lib.view_hours_worked_per_day_summary(timesheet))
     _logger.info("Script ends here")
 
 
